#[repr(C)]pub struct Function {
pub id: Record<u64, 1, NO_OPT_ZERO>,
pub name: Record<StringOffset, 2, OPT_ZERO>,
pub system_name: Record<StringOffset, 3, OPT_ZERO>,
pub filename: Record<StringOffset, 4, OPT_ZERO>,
}Expand description
Represents a function in a profile. Omits the start line because it’s not useful to Datadog right now, so we save the bytes/ops.
Fields
id: Record<u64, 1, NO_OPT_ZERO>Unique nonzero id for the function.
name: Record<StringOffset, 2, OPT_ZERO>Name of the function, in human-readable form if available.
system_name: Record<StringOffset, 3, OPT_ZERO>Name of the function, as identified by the system. For instance, it can be a C++ mangled name.
filename: Record<StringOffset, 4, OPT_ZERO>Source file containing the function.