Mapping

Struct Mapping 

#[repr(C)]
pub struct Mapping { pub id: Record<u64, 1, NO_OPT_ZERO>, pub memory_start: Record<u64, 2, OPT_ZERO>, pub memory_limit: Record<u64, 3, OPT_ZERO>, pub file_offset: Record<u64, 4, OPT_ZERO>, pub filename: Record<StringOffset, 5, OPT_ZERO>, pub build_id: Record<StringOffset, 6, OPT_ZERO>, }
Represents a mapping in a profile. The boolean fields have been omitted to save bytes/CPU since they are unused in Datadog.

Fields

id: Record<u64, 1, NO_OPT_ZERO>

Unique nonzero id for the mapping.

memory_start: Record<u64, 2, OPT_ZERO>

Address at which the binary (or DLL) is loaded into memory.

memory_limit: Record<u64, 3, OPT_ZERO>

The limit of the address range occupied by this mapping.

file_offset: Record<u64, 4, OPT_ZERO>

Offset in the binary that corresponds to the first mapped address.

filename: Record<StringOffset, 5, OPT_ZERO>

The object this entry is loaded from. This can be a filename on disk for the main binary and shared libraries or virtual abstractions like “[vdso]”.

build_id: Record<StringOffset, 6, OPT_ZERO>

A string that uniquely identifies a particular program version with high probability. E.g., for binaries generated by GNU tools, it could be the contents of the .note.gnu.build-id field.