pub struct StringOffset(/* private fields */);Expand description
Represents an offset into the Profile’s string table. Note that it cannot exceed u32 because an entire protobuf message must not be larger than or equal to 2 GiB. By the time you encode the tag and length prefix for each string, there’s no way to get this many unique-ish strings without first exceeding the protobuf 2 GiB limit.
A value of 0 means “no string” or “empty string” (they are synonymous). cbindgen:field-names=[offset]
Implementations