pub struct Tag(/* private fields */);Expand description
A tag is a combination of a wire_type, stored in the least significant three bits, and the field number that is defined in the .proto file.
Implementations