#[repr(C)]pub struct Location {
pub id: Record<u64, 1, NO_OPT_ZERO>,
pub mapping_id: Record<u64, 2, OPT_ZERO>,
pub address: Record<u64, 3, OPT_ZERO>,
pub line: Record<Line, 4, OPT_ZERO>,
}Expand description
Describes function and line table debug information. This only supports a
single Line, whereas protobuf supports zero or more. The is_folding
field is not omitted for size/CPU reasons.
Fields
id: Record<u64, 1, NO_OPT_ZERO>Unique nonzero id for the location. A profile could use instruction addresses or any integer sequence as ids.
mapping_id: Record<u64, 2, OPT_ZERO>The id of the corresponding profile.Mapping for this location. It can be unset if the mapping is unknown or not applicable for this profile type.
address: Record<u64, 3, OPT_ZERO>The instruction address for this location, if available. It should be
within Mapping.memory_start..Mapping.memory_limit for the
corresponding mapping. A non-leaf address may be in the middle of a
call instruction. It is up to display tools to find the beginning of
the instruction if necessary.
line: Record<Line, 4, OPT_ZERO>Trait Implementations
Sourceimpl Value for Location
Safety
The Default implementation will return all zero-representations.
impl Value for Location
Safety
The Default implementation will return all zero-representations.