#[repr(transparent)]pub struct Record<P: Value, const F: u32, const O: bool> {
pub value: P,
}Expand description
A record is responsible for encoding the field number, wire type and payload. The wire type tells the parser how big the payload after it is. For more details, refer to the Condensed Reference Card.
The P is the payload, the F is the field number, and O is whether to
apply the zero-sized optimization or not. Most of the time, it shouldn’t
matter if the optimization is applied. However, if something is part of
a repeated field, then applying the optimization would change the number
of elements in the array.
Fields
value: PThe value of the record. This is pub because of a quirk in Rust’s
orphan rules which prevent implementing From<Record<P,...> for P.